@@ -110,40 +110,31 @@ def _prettyprintdifflines(context, lines, blockno, lineidprefix, filea, reva,
     seenb = False
 
     for lineno, l in enumerate(lines, 1):
-        showa = True
-        showb = True
-
         match = RE_DIFF.match(l.decode('ascii'))
         if match is not None:
             ltype = b'difflineat'
             groups = match.groups()
             linea = int(groups[0])
             lineb = int(groups[1])
-            showa = False
-            showb = False
             seena = False
             seenb = False
         elif l.startswith(b'---'):
             ltype = b'difflineminus'
-            showa = False
-            showb = False
+            linea = 0
         elif l.startswith(b'+++'):
             ltype = b'difflineplus'
-            showa = False
-            showb = False
+            lineb = 0
         elif l.startswith(b'-'):
             # only increment if we've already seen a minus line
             if seena:
                 linea += 1
             ltype = b'difflineminus'
-            showb = False
             seena = True
         elif l.startswith(b'+'):
             # only increment if we've already seen a plus line
             if seenb:
                 lineb += 1
             ltype = b'difflineplus'
-            showa = False
             seenb = True
         else:
             # only increment if we've already seen a plus/minus line
@@ -162,8 +153,8 @@ def _prettyprintdifflines(context, lines, blockno, lineidprefix, filea, reva,
             b'filea': filea,
             b'fileb': fileb,
             b'line': l,
-            b'linea': showa and linea or b'',
-            b'lineb': showb and lineb or b'',
+            b'linea': linea,
+            b'lineb': lineb,
             b'lineid': lineidprefix + b"l%s" % difflineno,
             b'lineno': lineno,
             b'linenumber': b"% 8s" % difflineno,
@@ -265,12 +256,11 @@ def readme(context, mapping):
     # the ability to fallback if the prioritized one failed to render.
     for filename in ctx:
         lower = filename.lower()
-        if lower == b'readme.md':
+        if lower in [b'readme.txt', b'readme', b'readme.md']:
             raw_utf8 = ctx[filename].data().decode('utf-8')
             return cmarkgfm.markdown_to_html(raw_utf8).encode('utf-8')
 
-        if lower in [b'readme.txt', b'readme', b'readme.md']:
-            return ctx[filename].data().replace(b'\n', b'<br/>\n')
+    return ""
 
 
 def repo_custom_templater(orig, self, req):
